@@ -16,9 +16,12 @@ from linkmanager.db import DataBase
 
 app = Flask(__name__)
 assets = Environment(app)
+
 if settings.SERVER:
-    assets.directory = '/var/cache/linkmanager/static'
-    os.makedirs('/var/cache/linkmanager/static', mode=0o755)
+    static_path = '/var/cache/linkmanager/static'
+    assets.directory = static_path
+    if not os.path.exists(static_path):
+        os.makedirs(static_path, mode=0o755)
 
 db = DataBase()
 
